@@ -3,10 +3,13 @@ extern crate crossbeam_channel as channel;
 extern crate csv;
 extern crate csv_index;
 extern crate currency;
+extern crate chrono;
 extern crate dateparser;
 extern crate docopt;
 extern crate filetime;
 extern crate hlua;
+#[macro_use]
+extern crate lazy_static;
 extern crate mimalloc;
 extern crate num_cpus;
 extern crate rand;
@@ -14,9 +17,8 @@ extern crate regex;
 extern crate reverse_geocoder;
 extern crate serde;
 extern crate serde_json;
-extern crate stats;
 extern crate tabwriter;
-extern crate textwrap;
+//extern crate textwrap;
 extern crate threadpool;
 extern crate uuid;
 
@@ -83,7 +85,8 @@ macro_rules! command_list {
     rename      Rename the columns of CSV data efficiently
     replace     Replace patterns in CSV data
     reverse     Reverse rows of CSV data
-    search      Search CSV data with regexes
+    search      Search CSV data with a regex
+    searchset   Search CSV data with a regex set
     select      Select columns from CSV
     slice       Slice records from CSV
     sort        Sort CSV data
@@ -197,6 +200,7 @@ enum Command {
     Reverse,
     Sample,
     Search,
+    SearchSet,
     Select,
     Slice,
     Sort,
@@ -251,6 +255,7 @@ impl Command {
             Command::Reverse => cmd::reverse::run(argv),
             Command::Sample => cmd::sample::run(argv),
             Command::Search => cmd::search::run(argv),
+            Command::SearchSet => cmd::searchset::run(argv),
             Command::Select => cmd::select::run(argv),
             Command::Slice => cmd::slice::run(argv),
             Command::Sort => cmd::sort::run(argv),
