@@ -254,6 +254,7 @@ fn apply_datefmt() {
             svec!["September 17, 2012 10:09am EST"],
             svec!["Wed, 02 Jun 2021 06:31:39 GMT"],
             svec!["2009-01-20 05:00 EST"],
+            svec!["July 4, 2005"],            
             svec!["2021-05-01T01:17:02.604456Z"],
             svec!["This is not a date and it will not be reformatted"],
         ],
@@ -267,6 +268,7 @@ fn apply_datefmt() {
         svec!["2012-09-17T15:09:00+00:00"],
         svec!["2021-06-02T06:31:39+00:00"],
         svec!["2009-01-20T10:00:00+00:00"],
+        svec!["2005-07-04"],            
         svec!["2021-05-01T01:17:02.604456+00:00"],
         svec!["This is not a date and it will not be reformatted"],
     ];
